from _typeshed import Incomplete
from collections.abc import Iterable
from enum import Enum
from typing import Any
from typing_extensions import TypeAlias

from influxdb_client.client._base import _BaseWriteApi
from influxdb_client.client.write.point import Point
from influxdb_client.domain.write_precision import _WritePrecision

_DataClass: TypeAlias = Any  # any dataclass
_NamedTuple: TypeAlias = tuple[Any, ...]  # any NamedTuple
_Observable: TypeAlias = Any  # reactivex.Observable

logger: Incomplete

class WriteType(Enum):
    batching: int
    asynchronous: int
    synchronous: int

class WriteOptions:
    write_type: Incomplete
    batch_size: Incomplete
    flush_interval: Incomplete
    jitter_interval: Incomplete
    retry_interval: Incomplete
    max_retries: Incomplete
    max_retry_delay: Incomplete
    max_retry_time: Incomplete
    exponential_base: Incomplete
    write_scheduler: Incomplete
    def __init__(
        self,
        write_type: WriteType = ...,
        batch_size: int = ...,
        flush_interval: int = ...,
        jitter_interval: int = ...,
        retry_interval: int = ...,
        max_retries: int = ...,
        max_retry_delay: int = ...,
        max_retry_time: int = ...,
        exponential_base: int = ...,
        write_scheduler=...,
    ) -> None: ...
    def to_retry_strategy(self, **kwargs): ...

SYNCHRONOUS: Incomplete
ASYNCHRONOUS: Incomplete

class PointSettings:
    defaultTags: Incomplete
    def __init__(self, **default_tags) -> None: ...
    def add_default_tag(self, key, value) -> None: ...

class _BatchItemKey:
    bucket: Incomplete
    org: Incomplete
    precision: Incomplete
    def __init__(self, bucket, org, precision=...) -> None: ...
    def __hash__(self) -> int: ...
    def __eq__(self, o: object) -> bool: ...

class _BatchItem:
    key: Incomplete
    data: Incomplete
    size: Incomplete
    def __init__(self, key: _BatchItemKey, data, size: int = ...) -> None: ...
    def to_key_tuple(self) -> tuple[str, str, str]: ...

class _BatchResponse:
    data: Incomplete
    exception: Incomplete
    def __init__(self, data: _BatchItem, exception: Exception | None = ...) -> None: ...

class WriteApi(_BaseWriteApi):
    def __init__(
        self, influxdb_client, write_options: WriteOptions = ..., point_settings: PointSettings = ..., **kwargs
    ) -> None: ...
    def write(
        self,
        bucket: str,
        org: str | None = ...,
        record: str
        | Iterable[str]
        | Point
        | Iterable[Point]
        | dict[Incomplete, Incomplete]
        | Iterable[dict[Incomplete, Incomplete]]
        | bytes
        | Iterable[bytes]
        | _Observable
        | _NamedTuple
        | Iterable[_NamedTuple]
        | _DataClass
        | Iterable[_DataClass] = ...,
        write_precision: _WritePrecision = ...,
        **kwargs,
    ) -> Any: ...
    def flush(self) -> None: ...
    def close(self) -> None: ...
    def __enter__(self): ...
    def __exit__(self, exc_type, exc_val, exc_tb) -> None: ...
    def __del__(self) -> None: ...



from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class AuthorizationsService(_BaseService):
    def __init__(self, api_client: Incomplete | None = ...) -> None: ...
    def delete_authorizations_id(self, auth_id, **kwargs): ...
    def delete_authorizations_id_with_http_info(self, auth_id, **kwargs): ...
    async def delete_authorizations_id_async(self, auth_id, **kwargs): ...
    def get_authorizations(self, **kwargs): ...
    def get_authorizations_with_http_info(self, **kwargs): ...
    async def get_authorizations_async(self, **kwargs): ...
    def get_authorizations_id(self, auth_id, **kwargs): ...
    def get_authorizations_id_with_http_info(self, auth_id, **kwargs): ...
    async def get_authorizations_id_async(self, auth_id, **kwargs): ...
    def patch_authorizations_id(self, auth_id, authorization_update_request, **kwargs): ...
    def patch_authorizations_id_with_http_info(self, auth_id, authorization_update_request, **kwargs): ...
    async def patch_authorizations_id_async(self, auth_id, authorization_update_request, **kwargs): ...
    def post_authorizations(self, authorization_post_request, **kwargs): ...
    def post_authorizations_with_http_info(self, authorization_post_request, **kwargs): ...
    async def post_authorizations_async(self, authorization_post_request, **kwargs): ...



from _typeshed import Incomplete

from influxdb_client.domain.notification_endpoint_discriminator import NotificationEndpointDiscriminator

class PagerDutyNotificationEndpoint(NotificationEndpointDiscriminator):
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        client_url: Incomplete | None = ...,
        routing_key: Incomplete | None = ...,
        id: Incomplete | None = ...,
        org_id: Incomplete | None = ...,
        user_id: Incomplete | None = ...,
        created_at: Incomplete | None = ...,
        updated_at: Incomplete | None = ...,
        description: Incomplete | None = ...,
        name: Incomplete | None = ...,
        status: str = ...,
        labels: Incomplete | None = ...,
        links: Incomplete | None = ...,
        type: str = ...,
    ) -> None: ...
    @property
    def client_url(self): ...
    @client_url.setter
    def client_url(self, client_url) -> None: ...
    @property
    def routing_key(self): ...
    @routing_key.setter
    def routing_key(self, routing_key) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from influxdb_client.domain.http_notification_rule_base import HTTPNotificationRuleBase

class HTTPNotificationRule(HTTPNotificationRuleBase):
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        type: str = ...,
        url: Incomplete | None = ...,
        latest_completed: Incomplete | None = ...,
        last_run_status: Incomplete | None = ...,
        last_run_error: Incomplete | None = ...,
        id: Incomplete | None = ...,
        endpoint_id: Incomplete | None = ...,
        org_id: Incomplete | None = ...,
        task_id: Incomplete | None = ...,
        owner_id: Incomplete | None = ...,
        created_at: Incomplete | None = ...,
        updated_at: Incomplete | None = ...,
        status: Incomplete | None = ...,
        name: Incomplete | None = ...,
        sleep_until: Incomplete | None = ...,
        every: Incomplete | None = ...,
        offset: Incomplete | None = ...,
        runbook_link: Incomplete | None = ...,
        limit_every: Incomplete | None = ...,
        limit: Incomplete | None = ...,
        tag_rules: Incomplete | None = ...,
        description: Incomplete | None = ...,
        status_rules: Incomplete | None = ...,
        labels: Incomplete | None = ...,
        links: Incomplete | None = ...,
    ) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class RestoredBucketMappings:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self, id: Incomplete | None = ..., name: Incomplete | None = ..., shard_mappings: Incomplete | None = ...
    ) -> None: ...
    @property
    def id(self): ...
    @id.setter
    def id(self, id) -> None: ...
    @property
    def name(self): ...
    @name.setter
    def name(self, name) -> None: ...
    @property
    def shard_mappings(self): ...
    @shard_mappings.setter
    def shard_mappings(self, shard_mappings) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete, Self

from influxdb_client.client._base import _BaseClient
from influxdb_client.client.delete_api_async import DeleteApiAsync
from influxdb_client.client.query_api import QueryOptions
from influxdb_client.client.query_api_async import QueryApiAsync
from influxdb_client.client.write_api import PointSettings
from influxdb_client.client.write_api_async import WriteApiAsync

logger: Incomplete

class InfluxDBClientAsync(_BaseClient):
    api_client: Incomplete
    def __init__(
        self,
        url: str,
        token: str | None = ...,
        org: str | None = ...,
        debug: bool | None = ...,
        timeout: int = ...,
        enable_gzip: bool = ...,
        *,
        verify_ssl: bool = ...,
        ssl_ca_cert: Incomplete | None = ...,
        cert_file: Incomplete | None = ...,
        cert_key_file: Incomplete | None = ...,
        cert_key_password: Incomplete | None = ...,
        ssl_context: Incomplete | None = ...,
        proxy: Incomplete | None = ...,
        proxy_headers: Incomplete | None = ...,
        connection_pool_maxsize: int = ...,
        username: Incomplete | None = ...,
        password: Incomplete | None = ...,
        auth_basic: bool = ...,
        retries: bool | Incomplete = ...,
        profilers: Incomplete | None = ...,
    ) -> None: ...
    async def __aenter__(self: Self) -> Self: ...
    async def __aexit__(self, exc_type: object, exc: object, tb: object) -> None: ...
    async def close(self) -> None: ...
    @classmethod
    def from_config_file(cls, config_file: str = ..., debug: Incomplete | None = ..., enable_gzip: bool = ..., **kwargs): ...
    @classmethod
    def from_env_properties(cls, debug: Incomplete | None = ..., enable_gzip: bool = ..., **kwargs): ...
    async def ping(self) -> bool: ...
    async def version(self) -> str: ...
    async def build(self) -> str: ...
    def query_api(self, query_options: QueryOptions = ...) -> QueryApiAsync: ...
    def write_api(self, point_settings: PointSettings = ...) -> WriteApiAsync: ...
    def delete_api(self) -> DeleteApiAsync: ...



from _typeshed import Incomplete

class CellLinks:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, _self: Incomplete | None = ..., view: Incomplete | None = ...) -> None: ...
    @property
    def view(self): ...
    @view.setter
    def view(self, view) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from influxdb_client.domain.threshold_base import ThresholdBase

class LesserThreshold(ThresholdBase):
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self, type: str = ..., value: Incomplete | None = ..., level: Incomplete | None = ..., all_values: Incomplete | None = ...
    ) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    @property
    def value(self): ...
    @value.setter
    def value(self, value) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from urllib3 import HTTPResponse

logger: Incomplete

class InfluxDBError(Exception):
    response: Incomplete
    message: Incomplete
    retry_after: Incomplete
    def __init__(self, response: HTTPResponse | None = ..., message: str | None = ...) -> None: ...



from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class CellsService(_BaseService):
    def __init__(self, api_client: Incomplete | None = ...) -> None: ...
    def delete_dashboards_id_cells_id(self, dashboard_id, cell_id, **kwargs): ...
    def delete_dashboards_id_cells_id_with_http_info(self, dashboard_id, cell_id, **kwargs): ...
    async def delete_dashboards_id_cells_id_async(self, dashboard_id, cell_id, **kwargs): ...
    def get_dashboards_id_cells_id_view(self, dashboard_id, cell_id, **kwargs): ...
    def get_dashboards_id_cells_id_view_with_http_info(self, dashboard_id, cell_id, **kwargs): ...
    async def get_dashboards_id_cells_id_view_async(self, dashboard_id, cell_id, **kwargs): ...
    def patch_dashboards_id_cells_id(self, dashboard_id, cell_id, cell_update, **kwargs): ...
    def patch_dashboards_id_cells_id_with_http_info(self, dashboard_id, cell_id, cell_update, **kwargs): ...
    async def patch_dashboards_id_cells_id_async(self, dashboard_id, cell_id, cell_update, **kwargs): ...
    def patch_dashboards_id_cells_id_view(self, dashboard_id, cell_id, view, **kwargs): ...
    def patch_dashboards_id_cells_id_view_with_http_info(self, dashboard_id, cell_id, view, **kwargs): ...
    async def patch_dashboards_id_cells_id_view_async(self, dashboard_id, cell_id, view, **kwargs): ...
    def post_dashboards_id_cells(self, dashboard_id, create_cell, **kwargs): ...
    def post_dashboards_id_cells_with_http_info(self, dashboard_id, create_cell, **kwargs): ...
    async def post_dashboards_id_cells_async(self, dashboard_id, create_cell, **kwargs): ...
    def put_dashboards_id_cells(self, dashboard_id, cell, **kwargs): ...
    def put_dashboards_id_cells_with_http_info(self, dashboard_id, cell, **kwargs): ...
    async def put_dashboards_id_cells_async(self, dashboard_id, cell, **kwargs): ...



from _typeshed import Incomplete

class Replications:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, replications: Incomplete | None = ...) -> None: ...
    @property
    def replications(self): ...
    @replications.setter
    def replications(self, replications) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
